@@ -5,8 +5,8 @@
 ;; Author: Damian Barabonkov
 ;; Keywords: git tools vc
 ;; Homepage: https://github.com/DamianB-BitFlipper/magit-pre-commit.el
-;; Package-Version: 20260125.2259
-;; Package-Revision: 1b4056fc72c6
+;; Package-Version: 20260215.1854
+;; Package-Revision: 406d14e364b1
 ;; Package-Requires: ((emacs "29.1") (magit "3.0.0") (yaml "0.5.0"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -386,7 +386,10 @@ To enable, add to your init file:
   (define-key magit-mode-map magit-pre-commit-transient-prefix #'magit-pre-commit)
   ;; Add to magit-dispatch for discoverability
   (transient-insert-suffix 'magit-dispatch "!"
-    `(,magit-pre-commit-transient-prefix "Pre-commit" magit-pre-commit :if magit-pre-commit-available-p))
+    (list magit-pre-commit-transient-prefix
+          :description "Pre-commit"
+          :command 'magit-pre-commit
+          :if 'magit-pre-commit-available-p))
   ;; Add status section hook
   (magit-add-section-hook 'magit-status-sections-hook
                           #'magit-pre-commit--status-insert-section
